@@ -4,27 +4,16 @@
 #
 
 import unittest
-from unittest.mock import patch
+from unittest.mock import MagicMock
 
 from gvm.connections import (
     DEFAULT_TIMEOUT,
-    AbstractGvmConnection,
-    DebugConnection,
     GvmConnection,
-    XmlReader,
 )
+from gvm.connections._connection import AbstractGvmConnection
 from gvm.errors import GvmError
 
 
-class XmlReaderTestCase(unittest.TestCase):
-    def test_is_end_xml_false(self):
-        reader = XmlReader()
-        reader.start_xml()
-
-        false = reader.is_end_xml()
-        self.assertFalse(false)
-
-
 class TestConnection(AbstractGvmConnection):
     def connect(self) -> None:
         pass
@@ -34,29 +23,35 @@ class GvmConnectionTestCase(unittest.TestCase):
     # pylint: disable=protected-access
     def test_init_no_args(self):
         connection = TestConnection()
-        self.check_for_default_values(connection)
+
+        self.assertIsNone(connection._socket)
+        self.assertEqual(connection._timeout, DEFAULT_TIMEOUT)
 
     def test_init_with_none(self):
         connection = TestConnection(timeout=None)
-        self.check_for_default_values(connection)
 
-    def check_for_default_values(self, gvm_connection: GvmConnection):
-        self.assertIsNone(gvm_connection._socket)
-        self.assertEqual(gvm_connection._timeout, DEFAULT_TIMEOUT)
+        self.assertIsNone(connection._socket)
+        self.assertEqual(connection._timeout, DEFAULT_TIMEOUT)
+
+    def test_read_no_data(self):
+        read_mock = MagicMock()
+        read_mock.return_value = None
 
-    @patch("gvm.connections.AbstractGvmConnection._read")
-    def test_read_no_data(self, _read_mock):
-        _read_mock.return_value = None
         connection = TestConnection()
+        connection._read = read_mock
+
         with self.assertRaises(GvmError, msg="Remote closed the connection"):
             connection.read()
 
-    @patch("gvm.connections.AbstractGvmConnection._read")
-    def test_read_trigger_timeout(self, _read_mock):
+    def test_read_trigger_timeout(self):
         # mocking the response into two parts, so we run into the timeout
         # check in the loop
-        _read_mock.side_effect = [b"<foo>xyz<bar></bar>", b"</foo>"]
+        read_mock = MagicMock()
+        read_mock.side_effect = [b"<foo>xyz<bar></bar>", b"</foo>"]
+
         connection = TestConnection(timeout=0)
+        connection._read = read_mock
+
         with self.assertRaises(
             GvmError, msg="Timeout while reading the response"
         ):
@@ -65,9 +60,3 @@ class GvmConnectionTestCase(unittest.TestCase):
     def test_is_gvm_connection(self):
         connection = TestConnection()
         self.assertTrue(isinstance(connection, GvmConnection))
-
-
-class DebugConnectionTestCase(unittest.TestCase):
-    def test_is_gvm_connection(self):
-        connection = DebugConnection(TestConnection())
-        self.assertTrue(isinstance(connection, GvmConnection))
