@@ -6,7 +6,7 @@
 import unittest
 
 from gvm.errors import InvalidArgument
-from gvm.protocols.gmpv224 import HostsOrdering
+from gvm.protocols.gmp.requests.v224 import HostsOrdering
 
 
 class GetHostsOrderingFromStringTestCase(unittest.TestCase):
