@@ -13,13 +13,13 @@ from gvm.transforms import EtreeTransform
 class EtreeTransformTestCase(unittest.TestCase):
     def test_transform_response(self):
         transform = EtreeTransform()
-        result = transform("<foo/>")
+        result = transform(b"<foo/>")
 
         self.assertTrue(etree.iselement(result))
 
     def test_transform_more_complex_response(self):
         transform = EtreeTransform()
-        result = transform('<foo id="bar"><lorem/><ipsum/></foo>')
+        result = transform(b'<foo id="bar"><lorem/><ipsum/></foo>')
 
         self.assertTrue(etree.iselement(result))
         self.assertEqual(result.tag, "foo")
