@@ -11,10 +11,10 @@ from gvm.utils import to_base64
 class TestToBase64(unittest.TestCase):
     def test_to_base64(self):
         foo64 = to_base64("foo")
-        self.assertEqual(b"Zm9v", foo64)
+        self.assertEqual("Zm9v", foo64)
 
         bar64 = to_base64("bar")
-        self.assertEqual(b"YmFy", bar64)
+        self.assertEqual("YmFy", bar64)
 
 
 if __name__ == "__main__":
